"""
This script will parse a .csv file generated from Unreal into json
"""
import os
import json
import csv
from tkinter import filedialog

# Defines which CSV file to parse
def browseCSVFiles():
    filename = filedialog.askopenfilename(initialdir = "/",
                                          title = "Select a CSV File",
                                          filetypes = (("CSV files",
                                                        "*.csv*"),
                                                       ("all files",
                                                        "*.*")))
    return filename


def parseCsv(filepath):
    rowCount = 0
    csvDict = {}
    try:
        # Open and read the CSV file in utf-16 format 
        with open(f"{filepath}", newline='\n', encoding='utf-16') as csvfile:
            utrace = csv.reader(csvfile, delimiter=',')
            for row in utrace:
                if (rowCount == 0):
                    # Create the labels from row 0
                    csvDict["Labels"] = [row[0], row[1], row[2], row[3], row[4]]
                    rowCount = 1
                elif (rowCount == 1):
                    # Skip row 1
                    rowCount = 2
                    continue
                else:
                    # Create the dict from the rest of the rows
                    csvDict[row[0]] = [row[1], row[2], row[3], row[4]]
        return csvDict
    except FileNotFoundError:
        # Handle the file not found error
        print("The file was not found.")
        return 1
    except Exception as e:
        # Handle any other exceptions
        print(f"An error occurred: {e}")
        return 1


def writeToJSON(data_file):

    # Prompt the user to select a location and file name
    file_path = filedialog.asksaveasfilename(defaultextension=".json", filetypes=[("JSON files", "*.json"), ("All files", "*.*")])

    try:
        # Write dictionary to a JSON file
        with open(file_path, 'w') as json_file:
            json.dump(data_file, json_file, indent=4)

        print(f"Dictionary has been written to {file_path}.")
    except FileNotFoundError:
        # Handle the file not found error
        print("The file was not found.")
        return 1
    except Exception as e:
        # Handle any other exceptions
        print(f"An error occurred: {e}")
        return 1


# Main
def main():

    filename = browseCSVFiles()
    
    if (os.path.isfile(filename)):
        parsedCsvDict = parseCsv(filename)
        writeToJSON(parsedCsvDict)
        return 0
    else:
        print("No file specified - please select a *.csv file\n")
        return 1


if __name__ == "__main__":
    main()